|pypi| |travis| |coverage|

edc-pharmacy-dashboard
----------------------

EDC Pharmacy Dashboard


.. |pypi| image:: https://img.shields.io/pypi/v/edc-pharmacy-dashboard.svg
    :target: https://pypi.python.org/pypi/edc-pharmacy-dashboard
    
.. |travis| image:: https://travis-ci.com/clinicedc/edc-pharmacy-dashboard.svg?branch=develop
    :target: https://travis-ci.com/clinicedc/edc-pharmacy-dashboard
    
.. |coverage| image:: https://coveralls.io/repos/github/clinicedc/edc-pharmacy-dashboard/badge.svg?branch=develop
    :target: https://coveralls.io/github/clinicedc/edc-pharmacy-dashboard?branch=develop

